@@ -17,6 +17,7 @@ email                : lrssvtml (at) gmail (dot) com
  ***************************************************************************/
 Some portions of code were taken from https://code.google.com/p/pydee/
 """
+
 from __future__ import annotations
 
 import code
@@ -24,29 +25,25 @@ import os
 import re
 import sys
 import traceback
-from typing import (
-    Optional,
-    TYPE_CHECKING
-)
+from functools import partial
+from typing import Optional, TYPE_CHECKING
 from pathlib import Path
 from tempfile import NamedTemporaryFile
 
 from qgis.PyQt.Qsci import QsciScintilla
 from qgis.PyQt.QtCore import Qt, QCoreApplication
-from qgis.PyQt.QtGui import QKeySequence, QFontMetrics, QClipboard
-from qgis.PyQt.QtWidgets import QShortcut, QApplication
+from qgis.PyQt.QtGui import QKeySequence, QFontMetrics, QClipboard, QCursor
+from qgis.PyQt.QtWidgets import QShortcut, QApplication, QAction
 from qgis.core import (
     QgsApplication,
     Qgis,
-    QgsProcessingUtils
-)
-from qgis.gui import (
-    QgsCodeEditorPython,
-    QgsCodeEditor,
-    QgsCodeInterpreter
+    QgsProcessingUtils,
+    QgsSettingsTree,
 )
+from qgis.gui import QgsCodeEditorPython, QgsCodeEditor, QgsCodeInterpreter
 
 from .process_wrapper import ProcessWrapper
+
 if TYPE_CHECKING:
     from .console import PythonConsoleWidget
 
@@ -77,7 +74,6 @@ except ModuleNotFoundError:
     "from qgis.PyQt.QtWidgets import *",
     "from qgis.PyQt.QtNetwork import *",
     "from qgis.PyQt.QtXml import *",
-
     r"""
 def __parse_object(object=None):
     if not object:
@@ -101,6 +97,52 @@ def __parse_object(object=None):
         module = match[1]
         obj = match[2]
         return 'qt', module, obj
+""",
+    r"""
+def _help(object=None, api=Qgis.DocumentationApi.PyQgis, force_search=False):
+    '''
+    Link to the C++ or PyQGIS API documentation for the given object.
+    If no object is given, the main PyQGIS API page is opened.
+    If the object is not part of the QGIS API but is a Qt object the Qt documentation is opened.
+    '''
+
+    pythonSettingsTreeNode = QgsSettingsTree.node("gui").childNode("code-editor").childNode("python")
+    browserName = pythonSettingsTreeNode.childSetting('context-help-browser').valueAsVariant()
+    try:
+        browser = Qgis.DocumentationBrowser[browserName]
+    except KeyError:
+        browser = Qgis.DocumentationBrowser.DeveloperToolsPanel
+
+    if not object:
+        return iface.showApiDocumentation(api, browser=browser)
+
+    def search_or_home(object_str):
+        if not object_str:
+            return iface.showApiDocumentation(api, browser=browser)
+        if browser == Qgis.DocumentationBrowser.DeveloperToolsPanel and not QgsGui.hasWebEngine():
+            if force_search:
+                return iface.showApiDocumentation(Qgis.DocumentationApi.PyQgisSearch, object=object, browser=Qgis.DocumentationBrowser.SystemWebBrowser)
+            else:
+                return iface.showApiDocumentation(api, browser=browser)
+        else:
+            return iface.showApiDocumentation(Qgis.DocumentationApi.PyQgisSearch, object=object, browser=browser)
+
+    if isinstance(object, str):
+        try:
+            object = eval(object)
+        except (SyntaxError, NameError):
+            return search_or_home(object)
+
+    obj_info = __parse_object(object)
+    if not obj_info:
+        return search_or_home(object if isinstance(object, str) else None)
+
+    obj_type, module, class_name = obj_info
+    if obj_type == "qt":
+        api = Qgis.DocumentationApi.Qt
+
+    iface.showApiDocumentation(api, browser=browser, object=class_name, module=module)
+
 """,
     r"""
 def _api(object=None):
@@ -109,18 +151,7 @@ def _api(object=None):
     If no object is given, the main API page is opened.
     If the object is not part of the QGIS API but is a Qt object the Qt documentation is opened.
     '''
-    import webbrowser
-    api = __parse_object(object)
-
-    version = '' if 'master' in Qgis.QGIS_VERSION.lower() else re.findall(r'^\d.[0-9]*', Qgis.QGIS_VERSION)[0]
-
-    if not api:
-        webbrowser.open(f"https://qgis.org/api/{version}")
-    elif api[0] == 'qgis':
-        webbrowser.open(f"https://api.qgis.org/api/{version}/class{api[2]}.html")
-    elif api[0] == 'qt':
-        qtversion = '.'.join(qVersion().split(".")[:2])
-        webbrowser.open(f"https://doc.qt.io/qt-{qtversion}/{api[2].lower()}.html")
+    return _help(object, api=Qgis.DocumentationApi.CppQgis)
 """,
     r"""
 def _pyqgis(object=None):
@@ -129,19 +160,8 @@ def _pyqgis(object=None):
     If no object is given, the main PyQGIS API page is opened.
     If the object is not part of the QGIS API but is a Qt object the Qt documentation is opened.
     '''
-    import webbrowser
-    api = __parse_object(object)
-
-    version = 'master' if 'master' in Qgis.QGIS_VERSION.lower() else re.findall(r'^\d.[0-9]*', Qgis.QGIS_VERSION)[0]
-
-    if not api:
-        webbrowser.open(f"https://qgis.org/pyqgis/{version}")
-    elif api[0] == 'qgis':
-        webbrowser.open(f"https://qgis.org/pyqgis/{version}/{api[1]}/{api[2]}.html")
-    elif api[0] == 'qt':
-        qtversion = '.'.join(qVersion().split(".")[:2])
-        webbrowser.open(f"https://doc.qt.io/qt-{qtversion}/{api[2].lower()}.html")
-"""
+    return _help(object, api=Qgis.DocumentationApi.PyQgis)
+""",
 ]
 
 
@@ -199,7 +219,9 @@ class PythonInterpreter(QgsCodeInterpreter, code.InteractiveInterpreter):
                 # Use a temporary file to communicate the result to the inner interpreter
                 tmp = Path(NamedTemporaryFile(delete=False).name)
                 tmp.write_text(res, encoding="utf-8")
-                self.runsource(f'{varname} = Path("{tmp}").read_text(encoding="utf-8").split("\\n")')
+                self.runsource(
+                    f'{varname} = Path("{tmp}").read_text(encoding="utf-8").split("\\n")'
+                )
                 tmp.unlink()
                 self.sub_process = None
                 return 0
@@ -218,19 +240,25 @@ class PythonInterpreter(QgsCodeInterpreter, code.InteractiveInterpreter):
         res = 0
 
         import webbrowser
-        version = 'master' if 'master' in Qgis.QGIS_VERSION.lower() else \
-            re.findall(r'^\d.[0-9]*', Qgis.QGIS_VERSION)[0]
+
+        version = (
+            "master"
+            if "master" in Qgis.QGIS_VERSION.lower()
+            else re.findall(r"^\d.[0-9]*", Qgis.QGIS_VERSION)[0]
+        )
 
         if cmd == "?":
             self.shell.console_widget.shell_output.insertHelp()
-        elif cmd == '_pyqgis':
-            webbrowser.open("https://qgis.org/pyqgis/{}".format(version))
-        elif cmd == '_api':
-            webbrowser.open("https://qgis.org/api/{}".format('' if version == 'master' else version))
-        elif cmd == '_cookbook':
+        elif cmd == "_pyqgis":
+            self.shell.showApi(Qgis.DocumentationApi.PyQgis)
+        elif cmd == "_api":
+            self.shell.showApi(Qgis.DocumentationApi.CppQgis)
+        elif cmd == "_cookbook":
             webbrowser.open(
                 "https://docs.qgis.org/{}/en/docs/pyqgis_developer_cookbook/".format(
-                    'testing' if version == 'master' else version))
+                    "testing" if version == "master" else version
+                )
+            )
         else:
             self.buffer.append(cmd)
             src = "\n".join(self.buffer)
@@ -244,20 +272,21 @@ class PythonInterpreter(QgsCodeInterpreter, code.InteractiveInterpreter):
         if sys.stdout:
             sys.stdout.fire_keyboard_interrupt = False
         if len(txt) > 0:
-            sys.stdout.write(f'{self.promptForState()} {txt}\n')
+            sys.stdout.write(f"{self.promptForState()} {txt}\n")
 
-    def runsource(self, source, filename='<input>', symbol='single'):
+    def runsource(self, source, filename="<input>", symbol="single"):
         if sys.stdout:
             sys.stdout.fire_keyboard_interrupt = False
 
         hook = sys.excepthook
         try:
+
             def excepthook(etype, value, tb):
                 self.write("".join(traceback.format_exception(etype, value, tb)))
 
             sys.excepthook = excepthook
 
-            return super(PythonInterpreter, self).runsource(source, filename, symbol)
+            return super().runsource(source, filename, symbol)
         finally:
             sys.excepthook = hook
 
@@ -287,33 +316,45 @@ class ShellScintilla(QgsCodeEditorPython):
         # We set the ImmediatelyUpdateHistory flag here, as users can easily
         # crash QGIS by entering a Python command, and we don't want the
         # history leading to the crash lost...
-        super().__init__(console_widget, [], QgsCodeEditor.Mode.CommandInput,
-                         flags=QgsCodeEditor.Flags(QgsCodeEditor.Flag.CodeFolding | QgsCodeEditor.Flag.ImmediatelyUpdateHistory))
+        super().__init__(
+            console_widget,
+            [],
+            QgsCodeEditor.Mode.CommandInput,
+            flags=QgsCodeEditor.Flags(
+                QgsCodeEditor.Flag.CodeFolding
+                | QgsCodeEditor.Flag.ImmediatelyUpdateHistory
+            ),
+        )
 
         self.console_widget: PythonConsoleWidget = console_widget
         self._interpreter = PythonInterpreter(shell=self)
         self.setInterpreter(self._interpreter)
 
-        self.opening = ['(', '{', '[', "'", '"']
-        self.closing = [')', '}', ']', "'", '"']
+        self.opening = ["(", "{", "[", "'", '"']
+        self.closing = [")", "}", "]", "'", '"']
 
         self.setHistoryFilePath(
-            os.path.join(QgsApplication.qgisSettingsDirPath(), "console_history.txt"))
+            os.path.join(QgsApplication.qgisSettingsDirPath(), "console_history.txt")
+        )
 
         self.refreshSettingsShell()
 
         # Disable command key
         ctrl, shift = self.SCMOD_CTRL << 16, self.SCMOD_SHIFT << 16
-        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord('L') + ctrl)
-        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord('T') + ctrl)
-        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord('D') + ctrl)
-        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord('Z') + ctrl)
-        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord('Y') + ctrl)
-        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord('L') + ctrl + shift)
+        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord("L") + ctrl)
+        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord("T") + ctrl)
+        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord("D") + ctrl)
+        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord("Z") + ctrl)
+        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord("Y") + ctrl)
+        self.SendScintilla(QsciScintilla.SCI_CLEARCMDKEY, ord("L") + ctrl + shift)
 
         # New QShortcut = ctrl+space/ctrl+alt+space for Autocomplete
-        self.newShortcutCSS = QShortcut(QKeySequence(Qt.Modifier.CTRL | Qt.Modifier.SHIFT | Qt.Key.Key_Space), self)
-        self.newShortcutCAS = QShortcut(QKeySequence(Qt.Modifier.CTRL | Qt.Modifier.ALT | Qt.Key.Key_Space), self)
+        self.newShortcutCSS = QShortcut(
+            QKeySequence(Qt.Modifier.CTRL | Qt.Modifier.SHIFT | Qt.Key.Key_Space), self
+        )
+        self.newShortcutCAS = QShortcut(
+            QKeySequence(Qt.Modifier.CTRL | Qt.Modifier.ALT | Qt.Key.Key_Space), self
+        )
         self.newShortcutCSS.setContext(Qt.ShortcutContext.WidgetShortcut)
         self.newShortcutCAS.setContext(Qt.ShortcutContext.WidgetShortcut)
         self.newShortcutCAS.activated.connect(self.autoComplete)
@@ -336,18 +377,25 @@ class ShellScintilla(QgsCodeEditorPython):
         self._setMinimumHeight()
 
     def on_session_history_cleared(self):
-        msgText = QCoreApplication.translate('PythonConsole',
-                                             'Session history cleared successfully.')
+        msgText = QCoreApplication.translate(
+            "PythonConsole", "Session history cleared successfully."
+        )
         self.console_widget.callWidgetMessageBar(msgText)
 
     def on_persistent_history_cleared(self):
-        msgText = QCoreApplication.translate('PythonConsole',
-                                             'History cleared successfully.')
+        msgText = QCoreApplication.translate(
+            "PythonConsole", "History cleared successfully."
+        )
         self.console_widget.callWidgetMessageBar(msgText)
 
     def keyPressEvent(self, e):
 
-        if e.modifiers() & (Qt.KeyboardModifier.ControlModifier | Qt.KeyboardModifier.MetaModifier) and e.key() == Qt.Key.Key_C and not self.hasSelectedText():
+        if (
+            e.modifiers()
+            & (Qt.KeyboardModifier.ControlModifier | Qt.KeyboardModifier.MetaModifier)
+            and e.key() == Qt.Key.Key_C
+            and not self.hasSelectedText()
+        ):
             if self._interpreter.sub_process:
                 sys.stderr.write("Terminate child process\n")
                 self._interpreter.sub_process.kill()
@@ -436,25 +484,68 @@ class ShellScintilla(QgsCodeEditorPython):
         if sys.stderr:
             sys.stderr.write(txt)
 
-    def runFile(self, filename, override_file_name: Optional[str] = None):
+    def runFile(self, filename, override_file_name: str | None = None):
         filename = filename.replace("\\", "/")
         dirname = os.path.dirname(filename)
 
         # Append the directory of the file to the path and set __file__ to the filename
-        self._interpreter.execCommandImpl("sys.path.append({0})".format(
-            QgsProcessingUtils.stringToPythonLiteral(dirname)), False)
-        self._interpreter.execCommandImpl("__file__ = {0}".format(
-            QgsProcessingUtils.stringToPythonLiteral(filename)), False)
+        self._interpreter.execCommandImpl(
+            "sys.path.append({})".format(
+                QgsProcessingUtils.stringToPythonLiteral(dirname)
+            ),
+            False,
+        )
+        self._interpreter.execCommandImpl(
+            f"__file__ = {QgsProcessingUtils.stringToPythonLiteral(filename)}",
+            False,
+        )
 
         try:
             # Run the file
 
-            self.runCommand("exec(compile(Path({0}).read_text(), {1}, 'exec'))".format(
-                QgsProcessingUtils.stringToPythonLiteral(filename),
-                QgsProcessingUtils.stringToPythonLiteral(override_file_name or filename)),
-                skipHistory=True)
+            self.runCommand(
+                "exec(compile(Path({}).read_text(), {}, 'exec'))".format(
+                    QgsProcessingUtils.stringToPythonLiteral(filename),
+                    QgsProcessingUtils.stringToPythonLiteral(
+                        override_file_name or filename
+                    ),
+                ),
+                skipHistory=True,
+            )
         finally:
             # Remove the directory from the path and delete the __file__ variable
             self._interpreter.execCommandImpl("del __file__", False)
-            self._interpreter.execCommandImpl("sys.path.remove({0})".format(
-                QgsProcessingUtils.stringToPythonLiteral(dirname)), False)
+            self._interpreter.execCommandImpl(
+                "sys.path.remove({})".format(
+                    QgsProcessingUtils.stringToPythonLiteral(dirname)
+                ),
+                False,
+            )
+
+    def showApiDocumentation(self, text, force_search=False):
+        self._interpreter.execCommandImpl(
+            f"_help({repr(text)}, api=Qgis.DocumentationApi.PyQgis, force_search={force_search})",
+            show_input=False,
+        )
+
+    def showApi(self, api: Qgis.DocumentationApi):
+        self._interpreter.execCommandImpl(
+            f"_help(api=Qgis.DocumentationApi.{api.name})", show_input=False
+        )
+
+    def populateContextMenu(self, menu):
+
+        word = self.selectedText() or self.wordAtPoint(
+            self.mapFromGlobal(QCursor.pos())
+        )
+        if word:
+            context_help_action = QAction(
+                QgsApplication.getThemeIcon("mActionHelpContents.svg"),
+                QCoreApplication.translate("PythonConsole", "Context Help"),
+                menu,
+            )
+            context_help_action.triggered.connect(
+                partial(self.showApiDocumentation, word, force_search=True)
+            )
+            context_help_action.setShortcut("F1")
+            menu.addAction(context_help_action)
